@@ -1,4 +1,4 @@
-# Copyright 2004-2016 Tom Rothamel <pytom@bishoujo.us>
+# Copyright 2004-2017 Tom Rothamel <pytom@bishoujo.us>
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation files
@@ -331,6 +331,9 @@ class Displayable(renpy.object.Object):
 
         Displayables that contain state that can be manipulated by the user
         are never copied.
+
+        This should call _unique on children that have been copied before
+        setting its own _duplicatable flag.
         """
 
         return self
@@ -343,6 +346,16 @@ class Displayable(renpy.object.Object):
 
         return self
 
+    def _unique(self):
+        """
+        This is called when a displayable is "born" unique, which occurs
+        when there is only a single reference to it. What it does is to
+        manage the _duplicatable flag - setting it false unless one of
+        the displayable's children happens to be duplicatable.
+        """
+
+        return
+
     def parameterize(self, name, parameters):
         """
         Obsolete alias for _duplicate.
@@ -1642,6 +1655,8 @@ class Interface(object):
         if self.started:
             return
 
+        renpy.display.render.render_ready()
+
         # Kill off the presplash.
         renpy.display.presplash.end()
 
